@@ -480,8 +480,8 @@ Spgr_descr::Spgr_descr()
   set_preferred() method.
 
   \param name The spacegroup symbol or operators.
-  \param type The type of symbol:
-  Spacegroup::Symops, Spacegroup::Hall, Spacegroup::HM, Spacegroup::Number */
+  \param type The type of symbol: Spacegroup::Symops, Spacegroup::Hall,
+  Spacegroup::HM, Spacegroup::XHM, Spacegroup::Number */
 Spgr_descr::Spgr_descr( const String& symb, TYPE type )
 {
   using clipper::data::sgdata;
@@ -492,6 +492,8 @@ Spgr_descr::Spgr_descr( const String& symb, TYPE type )
   if ( type == Unknown ) {
     if      ( symbx.find_first_of( "()" ) != String::npos )
       type = Hall;
+    else if ( symbx.find_first_of( ":" ) != String::npos )
+      type = XHM;
     else if ( symbx.find_first_of( "," ) != String::npos )
       type = Symops;
     else if ( symbx.find_first_of( "ABCFHIPRSTQ" ) == String::npos )
@@ -501,32 +503,43 @@ Spgr_descr::Spgr_descr( const String& symb, TYPE type )
 
   // now make the ops
   int i;
-  int num;
   Symop_codes ops;
 
-  switch (type) {
-  case Symops:
-    ops.init_symops( symbx ); break;
-  case Hall:
-    ops.init_hall( symbx ); break;
-  case HM:
+  if ( type == Symops ) {
+    ops.init_symops( symbx );
+  } else if ( type == Hall ) {
+    ops.init_hall( symbx );
+  } else if ( type == XHM ) {
+    char ext = ' ';
+    size_t c = symbx.find_first_of( ":" );
+    if ( c != String::npos ) {
+      if ( c+1 < symbx.length() ) ext = symbx[c+1];
+      symbx = symbx.substr(0,c);
+      symbx = symbx.trim();
+    }
+    for ( i = 0; i < data::sgdata_size; i++ )
+      if ( symbx == String( sgdata[i].hm ) && sgdata[i].ext == ext ) break;
+    if ( i == data::sgdata_size )
+      Message::message( Message_fatal( "Spgr_descr: No such HM symbol" ) );
+    ops.init_hall( String( sgdata[i].hall ) );
+  } else if ( type == HM ) {
     for ( i = 0; i < data::sgdata_size; i++ )
       if ( symbx == String( sgdata[i].hm ) &&
 	   ( sgdata[i].ext == pref_12 || sgdata[i].ext == pref_hr ||
 	     sgdata[i].ext == ' ' ) ) break;
     if ( i == data::sgdata_size )
       Message::message( Message_fatal( "Spgr_descr: No such HM symbol" ) );
-    ops.init_hall( String( sgdata[i].hall ) ); break;
-  case Number:
-    num = symbx.i();
+    ops.init_hall( String( sgdata[i].hall ) );
+  } else if ( type == Number ) {
+    int num = symbx.i();
     for ( i = 0; i < data::sgdata_size; i++ )
       if ( num == sgdata[i].num &&
 	   ( sgdata[i].ext == pref_12 || sgdata[i].ext == pref_hr ||
 	     sgdata[i].ext == ' ' ) ) break;
     if ( i == data::sgdata_size )
       Message::message( Message_fatal( "Spgr_descr: No such SG number" ) );
-    ops.init_hall( String( sgdata[i].hall ) ); break;
-  case Unknown:
+    ops.init_hall( String( sgdata[i].hall ) );
+  } else {
     for ( i = 0; i < data::sgdata_size; i++ )  // try H-M then Hall.
       if ( symbx == String( sgdata[i].hm ) &&
 	   ( sgdata[i].ext == pref_12 || sgdata[i].ext == pref_hr ||
@@ -827,11 +840,23 @@ String Spgr_cacheobj::format() const
 
 // spacegroup object
 
+// Null ASU function and symops
+Symop  SYMOP_NULL  = Symop( RTop_frac::identity() );
+bool ASU_NULL( const int& h, const int& k, const int& l ) { return true; }
+
 /*! Construct null or P1 spacegroup. This is faster than the normal
   constructor.
   \param type Spacegroup::Null or Spacegroup::P1 */
 Spacegroup::Spacegroup( TYPE type )
-{ if ( type == P1 ) init( Spgr_descr( "x,y,z", Spgr_descr::Symops ) ); }
+{
+  if ( type == P1 ) {
+    init( Spgr_descr( "x,y,z", Spgr_descr::Symops ) );
+  } else {
+    nsym = nsymp = 1;  // workaround to enable handling of reflection data with null spacegroup
+    symops = &SYMOP_NULL;
+    asufn = ASU_NULL;
+  }
+}
 
 /*! Construct a spacegroup and initialise with a spacegroup description.
   \param spgr_descr The spacegroup description. */
@@ -852,6 +877,7 @@ void Spacegroup::init( const Spgr_descr& spgr_descr )
   nsym  = cacheref.data().nsym;
   nsymn = cacheref.data().nsymn;
   nsymi = cacheref.data().nsymi;
+  nsymc = cacheref.data().nsymc;
   nsymp = cacheref.data().nsymp;
   asufn = data::lgdata[cacheref.data().lgrp].asufn;
 }
